Index: /issm/trunk/src/c/EnumDefinitions/EnumDefinitions.h
===================================================================
--- /issm/trunk/src/c/EnumDefinitions/EnumDefinitions.h	(revision 9624)
+++ /issm/trunk/src/c/EnumDefinitions/EnumDefinitions.h	(revision 9625)
@@ -34,4 +34,5 @@
 	SettingsLowmemEnum,
 	SettingsIoGatherEnum,
+	MiscellaneousNameEnum, //FIXME: only used by qmu, should not be marshalled (already in queueing script)
 	/*}}}*/
 	/*Datasets {{{1*/
@@ -417,5 +418,4 @@
 	PrognosticDGEnum,
 	PressureloadEnum,
-	NameEnum,
 	VerticesTypeEnum,
 	SpcvzEnum,
Index: /issm/trunk/src/c/modules/EnumToStringx/EnumToStringx.cpp
===================================================================
--- /issm/trunk/src/c/modules/EnumToStringx/EnumToStringx.cpp	(revision 9624)
+++ /issm/trunk/src/c/modules/EnumToStringx/EnumToStringx.cpp	(revision 9625)
@@ -38,4 +38,5 @@
 		case SettingsLowmemEnum : return "SettingsLowmem";
 		case SettingsIoGatherEnum : return "SettingsIoGather";
+		case MiscellaneousNameEnum : return "MiscellaneousName";
 		case ConstraintsEnum : return "Constraints";
 		case ElementsEnum : return "Elements";
@@ -360,5 +361,4 @@
 		case PrognosticDGEnum : return "PrognosticDG";
 		case PressureloadEnum : return "Pressureload";
-		case NameEnum : return "Name";
 		case VerticesTypeEnum : return "VerticesType";
 		case SpcvzEnum : return "Spcvz";
Index: /issm/trunk/src/c/modules/ModelProcessorx/Qmu/CreateParametersQmu.cpp
===================================================================
--- /issm/trunk/src/c/modules/ModelProcessorx/Qmu/CreateParametersQmu.cpp	(revision 9624)
+++ /issm/trunk/src/c/modules/ModelProcessorx/Qmu/CreateParametersQmu.cpp	(revision 9625)
@@ -68,5 +68,5 @@
 	if(dakota_analysis){
 
-		iomodel->Constant(&name,NameEnum);
+		iomodel->Constant(&name,MiscellaneousNameEnum);
 		iomodel->Constant(&numberofresponses,NumberOfResponsesEnum);
 		iomodel->Constant(&numberofvertices,NumberOfVerticesEnum);
Index: /issm/trunk/src/c/modules/StringToEnumx/StringToEnumx.cpp
===================================================================
--- /issm/trunk/src/c/modules/StringToEnumx/StringToEnumx.cpp	(revision 9624)
+++ /issm/trunk/src/c/modules/StringToEnumx/StringToEnumx.cpp	(revision 9625)
@@ -36,4 +36,5 @@
 	else if (strcmp(name,"SettingsLowmem")==0) return SettingsLowmemEnum;
 	else if (strcmp(name,"SettingsIoGather")==0) return SettingsIoGatherEnum;
+	else if (strcmp(name,"MiscellaneousName")==0) return MiscellaneousNameEnum;
 	else if (strcmp(name,"Constraints")==0) return ConstraintsEnum;
 	else if (strcmp(name,"Elements")==0) return ElementsEnum;
@@ -358,5 +359,4 @@
 	else if (strcmp(name,"PrognosticDG")==0) return PrognosticDGEnum;
 	else if (strcmp(name,"Pressureload")==0) return PressureloadEnum;
-	else if (strcmp(name,"Name")==0) return NameEnum;
 	else if (strcmp(name,"VerticesType")==0) return VerticesTypeEnum;
 	else if (strcmp(name,"Spcvz")==0) return SpcvzEnum;
Index: /issm/trunk/src/m/classes/clusters/castor.m
===================================================================
--- /issm/trunk/src/m/classes/clusters/castor.m	(revision 9624)
+++ /issm/trunk/src/m/classes/clusters/castor.m	(revision 9625)
@@ -58,5 +58,5 @@
 
 			 %retrieve parameters 
-			 modelname=md.name; 
+			 modelname=md.miscellaneous.name; 
 			 solution_type=md.private.solution; 
 
@@ -93,7 +93,7 @@
 				
 				%compress the files into one zip.
-				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.name '.bin ' md.name '.queue '  md.name '.petsc '];
+				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.miscellaneous.name '.bin ' md.miscellaneous.name '.queue '  md.miscellaneous.name '.petsc '];
 				if md.dakota_analysis,
-					compressstring=[compressstring md.name '.qmu.in'];
+					compressstring=[compressstring md.miscellaneous.name '.qmu.in'];
 				end
 				system(compressstring);
@@ -123,8 +123,8 @@
 
 			%What packages are we picking up from remote cluster
-			packages={[md.name '.outlog'],[md.name '.errlog']};
+			packages={[md.miscellaneous.name '.outlog'],[md.miscellaneous.name '.errlog']};
 			if md.dakota_analysis,
-				packages{end+1}=[md.name '.qmu.err'];
-				packages{end+1}=[md.name '.qmu.out'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.err'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.out'];
 				if isfield(md.qmu_params,'tabular_graphics_data'),
 					if md.qmu_params.tabular_graphics_data==true,
@@ -133,5 +133,5 @@
 				end
 			else
-				packages{end+1}=[md.name '.outbin'];
+				packages{end+1}=[md.miscellaneous.name '.outbin'];
 			end
 
Index: /issm/trunk/src/m/classes/clusters/cosmos.m
===================================================================
--- /issm/trunk/src/m/classes/clusters/cosmos.m	(revision 9624)
+++ /issm/trunk/src/m/classes/clusters/cosmos.m	(revision 9625)
@@ -58,5 +58,5 @@
 
 			 %retrieve parameters 
-			 modelname=md.name; 
+			 modelname=md.miscellaneous.name; 
 			 solution_type=md.private.solution; 
 
@@ -92,7 +92,7 @@
 				
 				%compress the files into one zip.
-				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.name '.bin ' md.name '.queue '  md.name '.petsc '];
+				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.miscellaneous.name '.bin ' md.miscellaneous.name '.queue '  md.miscellaneous.name '.petsc '];
 				if md.dakota_analysis,
-					compressstring=[compressstring md.name '.qmu.in'];
+					compressstring=[compressstring md.miscellaneous.name '.qmu.in'];
 				end
 				system(compressstring);
@@ -122,8 +122,8 @@
 
 			%What packages are we picking up from remote cluster
-			packages={[md.name '.outlog'],[md.name '.errlog']};
+			packages={[md.miscellaneous.name '.outlog'],[md.miscellaneous.name '.errlog']};
 			if md.dakota_analysis,
-				packages{end+1}=[md.name '.qmu.err'];
-				packages{end+1}=[md.name '.qmu.out'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.err'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.out'];
 				if isfield(md.qmu_params,'tabular_graphics_data'),
 					if md.qmu_params.tabular_graphics_data==true,
@@ -132,5 +132,5 @@
 				end
 			else
-				packages{end+1}=[md.name '.outbin'];
+				packages{end+1}=[md.miscellaneous.name '.outbin'];
 			end
 
Index: /issm/trunk/src/m/classes/clusters/gemini.m
===================================================================
--- /issm/trunk/src/m/classes/clusters/gemini.m	(revision 9624)
+++ /issm/trunk/src/m/classes/clusters/gemini.m	(revision 9625)
@@ -58,5 +58,5 @@
 
 			 %retrieve parameters 
-			 modelname=md.name; 
+			 modelname=md.miscellaneous.name; 
 			 solution_type=md.private.solution; 
 
@@ -93,7 +93,7 @@
 				
 				%compress the files into one zip.
-				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.name '.bin ' md.name '.queue '  md.name '.petsc '];
+				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.miscellaneous.name '.bin ' md.miscellaneous.name '.queue '  md.miscellaneous.name '.petsc '];
 				if md.dakota_analysis,
-					compressstring=[compressstring md.name '.qmu.in'];
+					compressstring=[compressstring md.miscellaneous.name '.qmu.in'];
 				end
 				system(compressstring);
@@ -123,8 +123,8 @@
 
 			%What packages are we picking up from remote cluster
-			packages={[md.name '.outlog'],[md.name '.errlog']};
+			packages={[md.miscellaneous.name '.outlog'],[md.miscellaneous.name '.errlog']};
 			if md.dakota_analysis,
-				packages{end+1}=[md.name '.qmu.err'];
-				packages{end+1}=[md.name '.qmu.out'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.err'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.out'];
 				if isfield(md.qmu_params,'tabular_graphics_data'),
 					if md.qmu_params.tabular_graphics_data==true,
@@ -133,5 +133,5 @@
 				end
 			else
-				packages{end+1}=[md.name '.outbin'];
+				packages{end+1}=[md.miscellaneous.name '.outbin'];
 			end
 
Index: /issm/trunk/src/m/classes/clusters/generic.m
===================================================================
--- /issm/trunk/src/m/classes/clusters/generic.m	(revision 9624)
+++ /issm/trunk/src/m/classes/clusters/generic.m	(revision 9625)
@@ -72,5 +72,5 @@
 		 
 			 %retrieve parameters
-			 modelname=md.name;
+			 modelname=md.miscellaneous.name;
 			 solution_type=md.private.solution;
 			 isvalgrind=md.debug.valgrind;
@@ -117,15 +117,15 @@
 			 %lauch command, to be executed via ssh
 			 launchcommand=['cd ' cluster.executionpath ' && rm -rf ./' md.private.runtimename ' && mkdir ' md.private.runtimename ...
-			                ' && cd ' md.private.runtimename ' && mv ../' md.private.runtimename '.tar.gz ./ && tar -zxf ' md.private.runtimename '.tar.gz  && source  ' md.name '.queue '];
+			                ' && cd ' md.private.runtimename ' && mv ../' md.private.runtimename '.tar.gz ./ && tar -zxf ' md.private.runtimename '.tar.gz  && source  ' md.miscellaneous.name '.queue '];
 
 			if ~strcmpi(options.batch,'yes'),
 				
 				%compress the files into one zip.
-				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.name '.bin ' md.name '.queue '  md.name '.petsc '];
+				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.miscellaneous.name '.bin ' md.miscellaneous.name '.queue '  md.miscellaneous.name '.petsc '];
 				if md.dakota_analysis,
-					compressstring=[compressstring md.name '.qmu.in'];
+					compressstring=[compressstring md.miscellaneous.name '.qmu.in'];
 				end
 				if cluster.interactive,
-					compressstring=[compressstring ' ' md.name '.errlog ' md.name '.outlog '];
+					compressstring=[compressstring ' ' md.miscellaneous.name '.errlog ' md.miscellaneous.name '.outlog '];
 				end
 				system(compressstring);
@@ -153,8 +153,8 @@
 
 			%What packages are we picking up from remote cluster
-			packages={[md.name '.outlog'],[md.name '.errlog']};
+			packages={[md.miscellaneous.name '.outlog'],[md.miscellaneous.name '.errlog']};
 			if md.dakota_analysis,
-				packages{end+1}=[md.name '.qmu.err'];
-				packages{end+1}=[md.name '.qmu.out'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.err'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.out'];
 				if isfield(md.qmu_params,'tabular_graphics_data'),
 					if md.qmu_params.tabular_graphics_data==true,
@@ -163,5 +163,5 @@
 				end
 			else
-				packages{end+1}=[md.name '.outbin'];
+				packages{end+1}=[md.miscellaneous.name '.outbin'];
 			end
 
Index: /issm/trunk/src/m/classes/clusters/pfe.m
===================================================================
--- /issm/trunk/src/m/classes/clusters/pfe.m	(revision 9624)
+++ /issm/trunk/src/m/classes/clusters/pfe.m	(revision 9625)
@@ -108,5 +108,5 @@
 
 			 %retrieve parameters 
-			 modelname=md.name; 
+			 modelname=md.miscellaneous.name; 
 			 solution_type=md.private.solution; 
 			 isvalgrind=md.debug.valgrind;
@@ -173,5 +173,5 @@
 			 if ~cluster.interactive, 
 				launchcommand=['cd ' cluster.executionpath ' && rm -rf ./' md.private.runtimename ' && mkdir ' md.private.runtimename ...
-			                ' && cd ' md.private.runtimename ' && mv ../' md.private.runtimename '.tar.gz ./ && tar -zxf ' md.private.runtimename '.tar.gz  && qsub ' md.name '.queue '];
+			                ' && cd ' md.private.runtimename ' && mv ../' md.private.runtimename '.tar.gz ./ && tar -zxf ' md.private.runtimename '.tar.gz  && qsub ' md.miscellaneous.name '.queue '];
 			else
 				launchcommand=['cd ' cluster.executionpath '/Interactive' num2str(cluster.interactive) ' && tar -zxf ' md.private.runtimename '.tar.gz'];
@@ -181,10 +181,10 @@
 				
 				%compress the files into one zip.
-				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.name '.bin ' md.name '.queue '  md.name '.petsc '];
+				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.miscellaneous.name '.bin ' md.miscellaneous.name '.queue '  md.miscellaneous.name '.petsc '];
 				if md.dakota_analysis,
-					compressstring=[compressstring md.name '.qmu.in '];
+					compressstring=[compressstring md.miscellaneous.name '.qmu.in '];
 				end
 				if cluster.interactive,
-					compressstring=[compressstring md.name '.run ' md.name '.errlog ' md.name '.outlog '];
+					compressstring=[compressstring md.miscellaneous.name '.run ' md.miscellaneous.name '.errlog ' md.miscellaneous.name '.outlog '];
 				end
 				system(compressstring);
@@ -230,11 +230,11 @@
 			%What packages are we picking up from remote cluster
 			if ~cluster.interactive,
-				packages={[md.name '.outlog'],[md.name '.errlog']};
+				packages={[md.miscellaneous.name '.outlog'],[md.miscellaneous.name '.errlog']};
 			else
 				packages={};
 			end
 			if md.dakota_analysis,
-				packages{end+1}=[md.name '.qmu.err'];
-				packages{end+1}=[md.name '.qmu.out'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.err'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.out'];
 				if isfield(md.qmu_params,'tabular_graphics_data'),
 					if md.qmu_params.tabular_graphics_data==true,
@@ -243,5 +243,5 @@
 				end
 			else
-				packages{end+1}=[md.name '.outbin'];
+				packages{end+1}=[md.miscellaneous.name '.outbin'];
 			end
 
Index: /issm/trunk/src/m/classes/clusters/pollux.m
===================================================================
--- /issm/trunk/src/m/classes/clusters/pollux.m	(revision 9624)
+++ /issm/trunk/src/m/classes/clusters/pollux.m	(revision 9625)
@@ -58,5 +58,5 @@
 
 			 %retrieve parameters 
-			 modelname=md.name; 
+			 modelname=md.miscellaneous.name; 
 			 solution_type=md.private.solution; 
 
@@ -93,7 +93,7 @@
 				
 				%compress the files into one zip.
-				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.name '.bin ' md.name '.queue '  md.name '.petsc '];
+				compressstring=['tar -zcf ' md.private.runtimename '.tar.gz ' md.miscellaneous.name '.bin ' md.miscellaneous.name '.queue '  md.miscellaneous.name '.petsc '];
 				if md.dakota_analysis,
-					compressstring=[compressstring md.name '.qmu.in'];
+					compressstring=[compressstring md.miscellaneous.name '.qmu.in'];
 				end
 				system(compressstring);
@@ -123,8 +123,8 @@
 
 			%What packages are we picking up from remote cluster
-			packages={[md.name '.outlog'],[md.name '.errlog']};
+			packages={[md.miscellaneous.name '.outlog'],[md.miscellaneous.name '.errlog']};
 			if md.dakota_analysis,
-				packages{end+1}=[md.name '.qmu.err'];
-				packages{end+1}=[md.name '.qmu.out'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.err'];
+				packages{end+1}=[md.miscellaneous.name '.qmu.out'];
 				if isfield(md.qmu_params,'tabular_graphics_data'),
 					if md.qmu_params.tabular_graphics_data==true,
@@ -133,5 +133,5 @@
 				end
 			else
-				packages{end+1}=[md.name '.outbin'];
+				packages{end+1}=[md.miscellaneous.name '.outbin'];
 			end
 
Index: /issm/trunk/src/m/classes/miscellaneous.m
===================================================================
--- /issm/trunk/src/m/classes/miscellaneous.m	(revision 9625)
+++ /issm/trunk/src/m/classes/miscellaneous.m	(revision 9625)
@@ -0,0 +1,38 @@
+%MISCELANEOUS class definition
+%
+%   Usage:
+%      miscellaneous=miscellaneous();
+
+classdef miscellaneous
+	properties (SetAccess=public) 
+		notes = modelfield('default','','marshall',false);
+		name  = modelfield('default','','marshall',true,'format','String');
+		dummy = modelfield('default',NaN,'marshall',false);
+	end
+	methods
+		function obj = miscellaneous(varargin) % {{{
+			switch nargin
+				case 0
+					obj=setdefaultparameters(obj);
+				case 1
+					in=varargin{1};
+					if (isa(in,'numeric') & in==0),
+						% requesting templates do nothing
+					else
+						error('constructor not supported');
+					end 
+				otherwise
+					error('constructor not supported');
+			end
+		end % }}}
+		function obj = setdefaultparameters(obj) % {{{
+
+			%first, use the defaults provided by the properties definition above. 
+			fieldnames=fields(obj);
+			for i=1:length(fieldnames),
+				fieldname=fieldnames{i};
+				obj.(fieldname)=obj.(fieldname).default;
+			end
+		end % }}}
+	end
+end
Index: /issm/trunk/src/m/enum/MiscellaneousNameEnum.m
===================================================================
--- /issm/trunk/src/m/enum/MiscellaneousNameEnum.m	(revision 9625)
+++ /issm/trunk/src/m/enum/MiscellaneousNameEnum.m	(revision 9625)
@@ -0,0 +1,11 @@
+function macro=MiscellaneousNameEnum()
+%MISCELLANEOUSNAMEENUM - Enum of MiscellaneousName
+%
+%   WARNING: DO NOT MODIFY THIS FILE
+%            this file has been automatically generated by src/c/EnumDefinitions/Synchronize.sh
+%            Please read src/c/EnumDefinitions/README for more information
+%
+%   Usage:
+%      macro=MiscellaneousNameEnum()
+
+macro=StringToEnum('MiscellaneousName');
Index: sm/trunk/src/m/enum/NameEnum.m
===================================================================
--- /issm/trunk/src/m/enum/NameEnum.m	(revision 9624)
+++ 	(revision )
@@ -1,11 +1,0 @@
-function macro=NameEnum()
-%NAMEENUM - Enum of Name
-%
-%   WARNING: DO NOT MODIFY THIS FILE
-%            this file has been automatically generated by src/c/EnumDefinitions/Synchronize.sh
-%            Please read src/c/EnumDefinitions/README for more information
-%
-%   Usage:
-%      macro=NameEnum()
-
-macro=StringToEnum('Name');
Index: /issm/trunk/src/m/kml/kml_mesh_write.m
===================================================================
--- /issm/trunk/src/m/kml/kml_mesh_write.m	(revision 9624)
+++ /issm/trunk/src/m/kml/kml_mesh_write.m	(revision 9625)
@@ -113,14 +113,14 @@
 
 kdoc=kml_document();
-kdoc.name      =sprintf('ISSM Mesh: %s',md.name);
+kdoc.name      =sprintf('ISSM Mesh: %s',md.miscellaneous.name);
 kdoc.open      =1;
 ifirst=true;
-for i=1:numel(md.notes)
-    if ~isempty(md.notes{i})
+for i=1:numel(md.miscellaneous.notes)
+    if ~isempty(md.miscellaneous.notes{i})
         if ~ifirst
             kdoc.descript  =[kdoc.descript sprintf('\n')];
         end
         ifirst=false;
-        kdoc.descript  =[kdoc.descript sprintf('%s',md.notes{i})];
+        kdoc.descript  =[kdoc.descript sprintf('%s',md.miscellaneous.notes{i})];
     end
 end
Index: /issm/trunk/src/m/model/addnote.m
===================================================================
--- /issm/trunk/src/m/model/addnote.m	(revision 9624)
+++ /issm/trunk/src/m/model/addnote.m	(revision 9625)
@@ -15,5 +15,5 @@
 	error('addnote error message: second input argument should be a string');
 end
-notes=md.notes;
+notes=md.miscellaneous.notes;
 
 if ischar(notes),
@@ -29,3 +29,3 @@
 end
 
-md.notes=newnotes;
+md.miscellaneous.notes=newnotes;
Index: /issm/trunk/src/m/model/ismodelselfconsistent.m
===================================================================
--- /issm/trunk/src/m/model/ismodelselfconsistent.m	(revision 9624)
+++ /issm/trunk/src/m/model/ismodelselfconsistent.m	(revision 9625)
@@ -43,5 +43,5 @@
 %}}}
 %NAME{{{1
-if isempty(md.name),
+if isempty(md.miscellaneous.name),
 	message(['model is not correctly configured: missing name!']);
 end
@@ -111,5 +111,5 @@
 if ~isempty(md.requested_outputs),
 	if(size(md.requested_outputs,2)~=1),
-		message(['model ' md.name ' requested outputs should be a column vector']);
+		message(['model ' md.miscellaneous.name ' requested outputs should be a column vector']);
 	end
 end
@@ -117,24 +117,24 @@
 %THICKNESS = SURFACE - BED {{{1
 if any((md.thickness-md.surface+md.bed)>tolerance),
-	message(['model not consistent: model ' md.name ' violates the equality thickness=surface-bed!']);
+	message(['model not consistent: model ' md.miscellaneous.name ' violates the equality thickness=surface-bed!']);
 end
 %GROUNDING LINE MIGRATION {{{1
 if ~ismember({md.groundingline_migration},{'None' 'AgressiveMigration' 'SoftMigration'}),
-	message(['model not consistent: model ' md.name ' groundingline_migration field should be ''None'' ''AgressiveMigration'' or ''SoftMigration''']);
+	message(['model not consistent: model ' md.miscellaneous.name ' groundingline_migration field should be ''None'' ''AgressiveMigration'' or ''SoftMigration''']);
 end
 if ~strcmp(md.groundingline_migration,'None'),
 	if (md.dim==3 | strcmpi(md.cluster.name,'none')),
-		message(['model ' md.name ' requesting grounding line migration, but grounding line module only implemented for 2d models and parallel runs!']);
+		message(['model ' md.miscellaneous.name ' requesting grounding line migration, but grounding line module only implemented for 2d models and parallel runs!']);
 	end
 	if isnan(md.bathymetry),
-		message(['model not consistent: model ' md.name ' requesting grounding line migration, but bathymetry is absent!']);
+		message(['model not consistent: model ' md.miscellaneous.name ' requesting grounding line migration, but bathymetry is absent!']);
 	end
 	pos=find(md.nodeonicesheet); 
 	if any(md.bed(pos)-md.bathymetry(pos)),
-		message(['model not consistent: model ' md.name ' bathymetry not equal to bed on icesheet!']);
+		message(['model not consistent: model ' md.miscellaneous.name ' bathymetry not equal to bed on icesheet!']);
 	end
 	pos=find(md.nodeoniceshelf); 
 	if any(md.bathymetry(pos)-md.bed(pos)>tolerance),
-		message(['model not consistent: model ' md.name ' bathymetry superior to bed on iceshelf!']);
+		message(['model not consistent: model ' md.miscellaneous.name ' bathymetry superior to bed on iceshelf!']);
 	end
 
@@ -152,5 +152,5 @@
 	if ~isempty(find(md.segmentmarkers>=2)),
 		%We have segments with rift markers, but no rift structure!
-		message(['model not consistent: model ' md.name ' should be processed for rifts (run meshprocessrifts)!']);
+		message(['model not consistent: model ' md.miscellaneous.name ' should be processed for rifts (run meshprocessrifts)!']);
 	end
 	%Check that rifts are filled with proper material
@@ -170,14 +170,14 @@
 end
 if ~ismember(md.settings.lowmem,[0 1]),
-	message(['model not consistent: model ' md.name ' settings.lowmem field should be 0 or 1']);
+	message(['model not consistent: model ' md.miscellaneous.name ' settings.lowmem field should be 0 or 1']);
 end
 if ~ismember(md.time_adapt,[0 1]),
-	message(['model not consistent: model ' md.name ' time_adapt field should be 0 or 1']);
+	message(['model not consistent: model ' md.miscellaneous.name ' time_adapt field should be 0 or 1']);
 end
 if ~ismember(md.hydrostatic_adjustment,{'Absolute' 'Incremental'}),
-	message(['model not consistent: model ' md.name ' hydrostatic_adjustment field should be AbsoluteEnum or IncrementalEnum']);
+	message(['model not consistent: model ' md.miscellaneous.name ' hydrostatic_adjustment field should be AbsoluteEnum or IncrementalEnum']);
 end
 if ~ismember({md.rheology_law},{'None' 'Paterson' 'Arrhenius'}),
-	message(['model not consistent: model ' md.name ' rheology_law field should be ''none'' ''paterson'' or ''arrhenius''']);
+	message(['model not consistent: model ' md.miscellaneous.name ' rheology_law field should be ''none'' ''paterson'' or ''arrhenius''']);
 end
 %}}}
@@ -204,8 +204,8 @@
 	num_costfunc=size(md.cm_responses,2);
 	if ~iscell(md.control_type)
-		message(['model not consistent: model ' md.name ' control_type field should be a cell of strings']);
+		message(['model not consistent: model ' md.miscellaneous.name ' control_type field should be a cell of strings']);
 	end
 	if ~ismember(md.control_type,{'Dhdt' 'DragCoefficient' 'RheologyBbar' 'Vx' 'Vy'});
-		message(['model not consistent: model ' md.name ' control_type field should be ''Dhdt'' ''DragCoefficient'' ''RheologyBbar'' ''Vx'' ''Vy''']);
+		message(['model not consistent: model ' md.miscellaneous.name ' control_type field should be ''Dhdt'' ''DragCoefficient'' ''RheologyBbar'' ''Vx'' ''Vy''']);
 	end
 
@@ -243,5 +243,5 @@
 		pos=find(md.thickness<=0);
 		if any(isnan(md.spcthickness(pos))),
-			message(['model not consistent: model ' md.name ' has some nodes with 0 thickness']);
+			message(['model not consistent: model ' md.miscellaneous.name ' has some nodes with 0 thickness']);
 		end
 	end
@@ -295,8 +295,8 @@
 	end
 	if(md.cfl_coefficient>1 | md.cfl_coefficient<0),
-		message(['model not consistent: model ' md.name ' cfl_coefficient field should between  0 and 1']);
+		message(['model not consistent: model ' md.miscellaneous.name ' cfl_coefficient field should between  0 and 1']);
 	end
 	if(md.cfl_coefficient>1 | md.cfl_coefficient<0),
-		message(['model not consistent: model ' md.name ' cfl_coefficient field should between  0 and 1']);
+		message(['model not consistent: model ' md.miscellaneous.name ' cfl_coefficient field should between  0 and 1']);
 	end
 	if ~ismember(md.isdiagnostic,[0 1]),
@@ -340,5 +340,5 @@
 
 	if(md.cfl_coefficient>1 | md.cfl_coefficient<0),
-		message(['model not consistent: model ' md.name ' cfl_coefficient field should between  0 and 1']);
+		message(['model not consistent: model ' md.miscellaneous.name ' cfl_coefficient field should between  0 and 1']);
 	end
 end
@@ -365,5 +365,5 @@
 			%SINGULAR
 			if ~any((~isnan(md.spcvx)+~isnan(md.spcvy))==2),
-				message(['model not consistent: model ' md.name ' is not well posed (singular). You need at least one node with fixed velocity!'])
+				message(['model not consistent: model ' md.miscellaneous.name ' is not well posed (singular). You need at least one node with fixed velocity!'])
 			end
 
@@ -371,5 +371,5 @@
 			%CHECK THAT EACH LINES CONTAINS ONLY NAN VALUES OR NO NAN VALUES
 			if any(sum(isnan(md.diagnostic_ref),2)~=0 & sum(isnan(md.diagnostic_ref),2)~=6),
-				message(['model not consistent: model ' md.name ' has problem with rotated spc. Each line of diagnostic_ref should contain either only NaN values or no NaN values']);
+				message(['model not consistent: model ' md.miscellaneous.name ' has problem with rotated spc. Each line of diagnostic_ref should contain either only NaN values or no NaN values']);
 			end
 			%CHECK THAT THE TWO VECTORS PROVIDED ARE ORTHOGONAL
@@ -378,5 +378,5 @@
 				if any(dot(md.diagnostic_ref(pos,1:3),md.diagnostic_ref(pos,4:6))),
 					dot(md.diagnostic_ref(pos,1:3),md.diagnostic_ref(pos,4:6))
-					message(['model not consistent: model ' md.name ' has problem with rotated spc. Vectors in diagnostic_ref (colums 1 to 3 and 4 to 6) must be orthogonal']);
+					message(['model not consistent: model ' md.miscellaneous.name ' has problem with rotated spc. Vectors in diagnostic_ref (colums 1 to 3 and 4 to 6) must be orthogonal']);
 				end
 
@@ -386,5 +386,5 @@
 				pos=find(sum(isnan(md.diagnostic_ref),2)==0  & md.nodeonmacayeal);
 				if any(md.diagnostic_ref(pos,3:5)~=0);
-					message(['model not consistent: model ' md.name ' has problem with rotated spc. The rotation should be in the (x,y) plane for 2D diagnostic models (nodeonmacayeal)']);
+					message(['model not consistent: model ' md.miscellaneous.name ' has problem with rotated spc. The rotation should be in the (x,y) plane for 2D diagnostic models (nodeonmacayeal)']);
 				end
 			end
@@ -464,5 +464,5 @@
 				pos=find(md.thickness<=0);
 				if any(isnan(md.spcthickness(pos))),
-					message(['model not consistent: model ' md.name ' has some nodes with 0 thickness']);
+					message(['model not consistent: model ' md.miscellaneous.name ' has some nodes with 0 thickness']);
 				end
 			end
@@ -493,5 +493,5 @@
 			%CHECK THAT WE ARE NOT FULLY CONSTRAINED
 			if ~any(~isnan(md.spctemperature))
-				message(['model not consistent: model ' md.name ' is totally constrained for temperature, no need to solve!']);
+				message(['model not consistent: model ' md.miscellaneous.name ' is totally constrained for temperature, no need to solve!']);
 			end
 
@@ -519,5 +519,5 @@
 				%CHECK SPCTEMPERATURE that are not NaN are >0.
 				if find(any(md.spctemperature(find(~isnan(md.spctemperature(1:md.numberofnodes,:))))<=0)),
-					message(['model not consistent: model ' md.name ' is constrained with negative or nil temperatures!']);
+					message(['model not consistent: model ' md.miscellaneous.name ' is constrained with negative or nil temperatures!']);
 				end
 
@@ -718,15 +718,15 @@
 		if size(field,1)==md.numberofnodes,
 			if ~size(field,2)==1,
-				message(['model not consistent: model ' md.name ': ' fields{i} ' should have only one column as there are md.numberofnodes lines']);
+				message(['model not consistent: model ' md.miscellaneous.name ': ' fields{i} ' should have only one column as there are md.numberofnodes lines']);
 			end
 		elseif size(field,1)==md.numberofnodes+1
 			if any(field(end,:)~=sort(field(end,:))),
-				message(['model not consistent: model ' md.name ': ' fields{i} ' columns should be chronological']);
+				message(['model not consistent: model ' md.miscellaneous.name ': ' fields{i} ' columns should be chronological']);
 			end
 			if any(field(end,1:end-1)==field(end,2:end)),
-				message(['model not consistent: model ' md.name ': ' fields{i} ' columns must not contain duplicate timesteps']);
+				message(['model not consistent: model ' md.miscellaneous.name ': ' fields{i} ' columns must not contain duplicate timesteps']);
 			end
 		else
-			message(['model not consistent: model ' md.name ': ' fields{i} ' should have md.numberofnodes or md.numberofnodes+1 lines']);
+			message(['model not consistent: model ' md.miscellaneous.name ': ' fields{i} ' should have md.numberofnodes or md.numberofnodes+1 lines']);
 		end
 	end
Index: /issm/trunk/src/m/model/loadresultsfromcluster.m
===================================================================
--- /issm/trunk/src/m/model/loadresultsfromcluster.m	(revision 9624)
+++ /issm/trunk/src/m/model/loadresultsfromcluster.m	(revision 9625)
@@ -16,12 +16,12 @@
 
 %read log files onto  fields
-if exist([md.name '.errlog'],'file'),
-	md.errlog=char(textread([md.name '.errlog'],'%s','delimiter','\n'));
+if exist([md.miscellaneous.name '.errlog'],'file'),
+	md.errlog=char(textread([md.miscellaneous.name '.errlog'],'%s','delimiter','\n'));
 else
 	md.errlog='';
 end
 
-if exist([md.name '.outlog'],'file'),
-	md.outlog=char(textread([md.name '.outlog'],'%s','delimiter','\n'));
+if exist([md.miscellaneous.name '.outlog'],'file'),
+	md.outlog=char(textread([md.miscellaneous.name '.outlog'],'%s','delimiter','\n'));
 else
 	md.outlog='';
@@ -33,14 +33,14 @@
 
 %If we are here, no errors in the solution sequence, call loadresultsfromdisk.
-md=loadresultsfromdisk(md,[md.name '.outbin']);
+md=loadresultsfromdisk(md,[md.miscellaneous.name '.outbin']);
 
 %erase the log and output files
 if md.dakota_analysis,
-	delete([['qmu' num2str(feature('GetPid')) '/'] md.name '.outlog']);
-	delete([['qmu' num2str(feature('GetPid')) '/']  md.name '.errlog']);
+	delete([['qmu' num2str(feature('GetPid')) '/'] md.miscellaneous.name '.outlog']);
+	delete([['qmu' num2str(feature('GetPid')) '/']  md.miscellaneous.name '.errlog']);
 else
-	delete([md.name '.outlog']);
-	delete([md.name '.errlog']);
-	delete([md.name '.outbin']);
+	delete([md.miscellaneous.name '.outlog']);
+	delete([md.miscellaneous.name '.errlog']);
+	delete([md.miscellaneous.name '.outbin']);
 	delete([md.private.runtimename '.tar.gz']);
 end
@@ -50,10 +50,10 @@
 if strcmpi(hostname,cluster.name),
 	if md.dakota_analysis,
-		delete([['qmu' num2str(feature('GetPid')) '/'] md.name '.bin']);
-		delete([['qmu' num2str(feature('GetPid')) '/'] md.name '.queue']);
+		delete([['qmu' num2str(feature('GetPid')) '/'] md.miscellaneous.name '.bin']);
+		delete([['qmu' num2str(feature('GetPid')) '/'] md.miscellaneous.name '.queue']);
 	else
-		delete([md.name '.bin']);
-		delete([md.name '.queue']);
-		delete([md.name '.petsc']);
+		delete([md.miscellaneous.name '.bin']);
+		delete([md.miscellaneous.name '.queue']);
+		delete([md.miscellaneous.name '.petsc']);
 	end
 end
Index: /issm/trunk/src/m/model/marshall.m
===================================================================
--- /issm/trunk/src/m/model/marshall.m	(revision 9624)
+++ /issm/trunk/src/m/model/marshall.m	(revision 9625)
@@ -8,10 +8,10 @@
 %      marshall(md)
 
-disp(['marshalling file ' md.name '.bin']);
+disp(['marshalling file ' md.miscellaneous.name '.bin']);
 
 %open file for binary writing
-fid=fopen([ md.name '.bin'],'wb');
+fid=fopen([ md.miscellaneous.name '.bin'],'wb');
 if fid==-1,
-	error(['marshall error message: could not open ' [md.name '.bin'],' file for binary writing']);
+	error(['marshall error message: could not open ' [md.miscellaneous.name '.bin'],' file for binary writing']);
 end
 
@@ -26,5 +26,5 @@
 st=fclose(fid);
 if st==-1,
-	error(['marshall error message: could not close file ' [md.name '.bin']]);
+	error(['marshall error message: could not close file ' [md.miscellaneous.name '.bin']]);
 end
 
Index: /issm/trunk/src/m/model/parameterization/parameterize.m
===================================================================
--- /issm/trunk/src/m/model/parameterization/parameterize.m	(revision 9624)
+++ /issm/trunk/src/m/model/parameterization/parameterize.m	(revision 9625)
@@ -54,7 +54,7 @@
 
 %Name and notes
-if isempty(md.name), 
+if isempty(md.miscellaneous.name), 
 	[path,root,ext]=fileparts(parametername);
-	md.name=root; 
+	md.miscellaneous.name=root; 
 end
 md=addnote(md,['Model created by using parameter file: ' parametername ' on: ' datestr(now)]);
Index: /issm/trunk/src/m/model/solve.m
===================================================================
--- /issm/trunk/src/m/model/solve.m	(revision 9624)
+++ /issm/trunk/src/m/model/solve.m	(revision 9625)
@@ -61,5 +61,5 @@
 
 %write a template file for issm to use, in parallel
-PetscFile(md.solver,[md.name '.petsc']);
+PetscFile(md.solver,[md.miscellaneous.name '.petsc']);
 
 %If running in parallel, we have a different way of launching the solution
Index: /issm/trunk/src/m/model/solveparallel.m
===================================================================
--- /issm/trunk/src/m/model/solveparallel.m	(revision 9624)
+++ /issm/trunk/src/m/model/solveparallel.m	(revision 9625)
@@ -14,5 +14,5 @@
 	%First, build a runtime name that is unique, that we will use to create 
 	%directories, name jobs, etc ...
-	c=clock; md.private.runtimename=sprintf('%s-%i-%i-%i-%i-%i-%i-%i',md.name,c(2),c(3),c(1),c(4),c(5),floor(c(6)),feature('GetPid'));
+	c=clock; md.private.runtimename=sprintf('%s-%i-%i-%i-%i-%i-%i-%i',md.miscellaneous.name,c(2),c(3),c(1),c(4),c(5),floor(c(6)),feature('GetPid'));
 
 	%Now, we need to build the queuing script, used by the cluster to launch the job.
Index: /issm/trunk/src/m/model/waitonlock.m
===================================================================
--- /issm/trunk/src/m/model/waitonlock.m	(revision 9624)
+++ /issm/trunk/src/m/model/waitonlock.m	(revision 9625)
@@ -14,5 +14,5 @@
 port=md.cluster.port;
 timelimit=md.waitonlock;
-filename=[executionpath '/' md.private.runtimename '/' md.name '.lock'];
+filename=[executionpath '/' md.private.runtimename '/' md.miscellaneous.name '.lock'];
 
 %waitonlock will work if the lock is on the same machine only: 
Index: /issm/trunk/src/m/qmu/postqmu.m
===================================================================
--- /issm/trunk/src/m/qmu/postqmu.m	(revision 9624)
+++ /issm/trunk/src/m/qmu/postqmu.m	(revision 9625)
@@ -4,5 +4,5 @@
 
 %  check to see if dakota returned errors in the err file
-qmuerrfile=[md.name '.qmu.err'];
+qmuerrfile=[md.miscellaneous.name '.qmu.err'];
 
 if exist(qmuerrfile,'file')
@@ -25,6 +25,6 @@
 
 %parse inputs and results from dakota
-qmuinfile=[md.name '.qmu.in'];
-qmuoutfile=[md.name '.qmu.out'];
+qmuinfile=[md.miscellaneous.name '.qmu.in'];
+qmuoutfile=[md.miscellaneous.name '.qmu.out'];
 
 %[method,dvar,dresp_in]=dakota_in_parse(qmuinfile);
Index: /issm/trunk/src/m/qmu/qmumarshall.m
===================================================================
--- /issm/trunk/src/m/qmu/qmumarshall.m	(revision 9624)
+++ /issm/trunk/src/m/qmu/qmumarshall.m	(revision 9625)
@@ -13,10 +13,10 @@
 end
 
-disp(['qmu marshalling file ' md.name '.bin']);
+disp(['qmu marshalling file ' md.miscellaneous.name '.bin']);
 
 %open file for binary adding 
-fid=fopen([ md.name '.bin'],'ab');
+fid=fopen([ md.miscellaneous.name '.bin'],'ab');
 if fid==-1,
-	error(['qmumarshall error message: could not open ' [md.name '.bin'],' file for binary adding']);
+	error(['qmumarshall error message: could not open ' [md.miscellaneous.name '.bin'],' file for binary adding']);
 end
 
@@ -66,5 +66,5 @@
 st=fclose(fid);
 if st==-1,
-	error(['qmumarshall error message: could not close file ' [md.name '.bin']]);
+	error(['qmumarshall error message: could not close file ' [md.miscellaneous.name '.bin']]);
 end
 
Index: /issm/trunk/src/m/qmu/qmuname.m
===================================================================
--- /issm/trunk/src/m/qmu/qmuname.m	(revision 9624)
+++ /issm/trunk/src/m/qmu/qmuname.m	(revision 9625)
@@ -13,3 +13,3 @@
 
 %modify model name by appending number to the name
-md.name=[md.name num2str(number)];
+md.miscellaneous.name=[md.miscellaneous.name num2str(number)];
Index: /issm/trunk/src/m/solutions/NewFemModel.m
===================================================================
--- /issm/trunk/src/m/solutions/NewFemModel.m	(revision 9624)
+++ /issm/trunk/src/m/solutions/NewFemModel.m	(revision 9625)
@@ -17,6 +17,6 @@
    femmodel.analysis_type_list=analysis_types;
 
-	issmprintf(VerboseMProcessor(),'\n   reading data from input file %s.bin...',md.name);
-   [femmodel.elements,femmodel.nodes,femmodel.vertices,femmodel.constraints,femmodel.loads,femmodel.materials,femmodel.parameters]=ModelProcessor([md.name '.bin'],solution_type,femmodel.analysis_type_list);
+	issmprintf(VerboseMProcessor(),'\n   reading data from input file %s.bin...',md.miscellaneous.name);
+   [femmodel.elements,femmodel.nodes,femmodel.vertices,femmodel.constraints,femmodel.loads,femmodel.materials,femmodel.parameters]=ModelProcessor([md.miscellaneous.name '.bin'],solution_type,femmodel.analysis_type_list);
    
 	%Initialize some fiels with empty celils
Index: /issm/trunk/src/m/solutions/flaim.m
===================================================================
--- /issm/trunk/src/m/solutions/flaim.m	(revision 9624)
+++ /issm/trunk/src/m/solutions/flaim.m	(revision 9625)
@@ -80,5 +80,5 @@
 
 display('Calling KMLMeshWrite.');
-KMLMeshWrite(md.name,md.notes,md.elements,md.nodeconnectivity,md.lat,md.long,md.part,md.flaim.criterion,options.cmap,filekml);
+KMLMeshWrite(md.miscellaneous.name,md.miscellaneous.notes,md.elements,md.nodeconnectivity,md.lat,md.long,md.part,md.flaim.criterion,options.cmap,filekml);
 %  for testing
 %filekml='issm-split-geikie1-targets.kml';
Index: /issm/trunk/src/m/solutions/issm.m
===================================================================
--- /issm/trunk/src/m/solutions/issm.m	(revision 9624)
+++ /issm/trunk/src/m/solutions/issm.m	(revision 9625)
@@ -19,5 +19,5 @@
 	
 	%process petsc options: 
-	femmodel.parameters=ParsePetscOptions(femmodel.parameters,[md.name '.petsc']);
+	femmodel.parameters=ParsePetscOptions(femmodel.parameters,[md.miscellaneous.name '.petsc']);
 
 	%retrieve parameters
Index: /issm/trunk/template
===================================================================
--- /issm/trunk/template	(revision 9624)
+++ /issm/trunk/template	(revision 9625)
@@ -63,9 +63,4 @@
 	elementonwater
 
-}}}
-rifts{{{
-	rifts
-	numrifts
-	riftproperties
 }}}
 materials{{{
@@ -82,9 +77,4 @@
 	rheology_n
 	rheology_law
-}}}
-friction{{{
-	drag_coefficient
-	drag_p
-	drag_q
 }}}
 flowequation{{{
@@ -225,9 +215,4 @@
 	vwgt -> vertex_weight
 }}}
-
-cluster{{{
-	waitonlock -> cluster dependent to be added to all cluster classes
-	-> already exists
-}}}
 timestepping{{{
 	dt ->time_step
@@ -236,30 +221,15 @@
 	cfl_coefficient
 }}}
+
+%To be completed
+cluster{{{
+	waitonlock -> cluster dependent to be added to all cluster classes
+	  -> already exists
+}}}
 results{{{
 	results_on_vertices
-	output_frequency
-	outlog
-	errlog
+	  output_frequency
+	  outlog
+	  errlog
 	  + all model results ??? (DiagnosticSolution and others?)
 }}}
-constants{{{
-	%not material dependent
-g
-yts
-referencetemperature
-}}}
-radaroverlay{{{
-	sarpwr %error message if database does not exist
-	sarxm
-	sarym
-}}}
-miscelaneous {{{
-	notes
-	name
-	dummy
-}}}
-private {{{
-	runtimename
-	solution_type -> erase and get this from the outbin
-	bamg
-}}}
Index: /issm/trunk/test/Miscellaneous/GJM_test1/SquareShelf.par
===================================================================
--- /issm/trunk/test/Miscellaneous/GJM_test1/SquareShelf.par	(revision 9624)
+++ /issm/trunk/test/Miscellaneous/GJM_test1/SquareShelf.par	(revision 9625)
@@ -40,3 +40,3 @@
 %Change name so that no test have the same name
 A=dbstack;
-if (length(A)>2), md.name=A(3).file(1:end-2); end
+if (length(A)>2), md.miscellaneous.name=A(3).file(1:end-2); end
Index: /issm/trunk/test/Par/79North.par
===================================================================
--- /issm/trunk/test/Par/79North.par	(revision 9624)
+++ /issm/trunk/test/Par/79North.par	(revision 9625)
@@ -47,3 +47,3 @@
 %Change name so that no test have the same name
 A=dbstack;
-if (length(A)>2), md.name=A(3).file(1:end-2); end
+if (length(A)>2), md.miscellaneous.name=A(3).file(1:end-2); end
Index: /issm/trunk/test/Par/Pig.par
===================================================================
--- /issm/trunk/test/Par/Pig.par	(revision 9624)
+++ /issm/trunk/test/Par/Pig.par	(revision 9625)
@@ -43,3 +43,3 @@
 %Change name so that no test have the same name
 A=dbstack;
-if (length(A)>2), md.name=A(3).file(1:end-2); end
+if (length(A)>2), md.miscellaneous.name=A(3).file(1:end-2); end
Index: /issm/trunk/test/Par/RoundSheetShelf.par
===================================================================
--- /issm/trunk/test/Par/RoundSheetShelf.par	(revision 9624)
+++ /issm/trunk/test/Par/RoundSheetShelf.par	(revision 9625)
@@ -89,3 +89,3 @@
 %Change name so that no test have the same name
 A=dbstack;
-if (length(A)>2), md.name=A(3).file(1:end-2); end
+if (length(A)>2), md.miscellaneous.name=A(3).file(1:end-2); end
Index: /issm/trunk/test/Par/SquareSheetConstrained.par
===================================================================
--- /issm/trunk/test/Par/SquareSheetConstrained.par	(revision 9624)
+++ /issm/trunk/test/Par/SquareSheetConstrained.par	(revision 9625)
@@ -46,3 +46,3 @@
 %Change name so that no test have the same name
 A=dbstack;
-if (length(A)>2), md.name=A(3).file(1:end-2); end
+if (length(A)>2), md.miscellaneous.name=A(3).file(1:end-2); end
Index: /issm/trunk/test/Par/SquareSheetShelf.par
===================================================================
--- /issm/trunk/test/Par/SquareSheetShelf.par	(revision 9624)
+++ /issm/trunk/test/Par/SquareSheetShelf.par	(revision 9625)
@@ -53,3 +53,3 @@
 %Change name so that no test have the same name
 A=dbstack;
-if (length(A)>2), md.name=A(3).file(1:end-2); end
+if (length(A)>2), md.miscellaneous.name=A(3).file(1:end-2); end
Index: /issm/trunk/test/Par/SquareShelf.par
===================================================================
--- /issm/trunk/test/Par/SquareShelf.par	(revision 9624)
+++ /issm/trunk/test/Par/SquareShelf.par	(revision 9625)
@@ -46,3 +46,3 @@
 %Change name so that no test have the same name
 A=dbstack;
-if (length(A)>2), md.name=A(3).file(1:end-2); end
+if (length(A)>2), md.miscellaneous.name=A(3).file(1:end-2); end
Index: /issm/trunk/test/Par/SquareShelfConstrained.par
===================================================================
--- /issm/trunk/test/Par/SquareShelfConstrained.par	(revision 9624)
+++ /issm/trunk/test/Par/SquareShelfConstrained.par	(revision 9625)
@@ -50,3 +50,3 @@
 %Change name so that no test have the same name
 A=dbstack;
-if (length(A)>2), md.name=A(3).file(1:end-2); end
+if (length(A)>2), md.miscellaneous.name=A(3).file(1:end-2); end

Index: /issm/trunk/src/m/classes/model/model.m
===================================================================
--- /issm/trunk/src/m/classes/model/model.m	(revision 9624)
+++ /issm/trunk/src/m/classes/model/model.m	(revision 9625)
@@ -23,10 +23,7 @@
 		 settings  = modelfield('default',0,'marshall',true);
 		 radaroverlay = modelfield('default',0,'marshall',false);
+		 miscellaneous = modelfield('default',0,'marshall',true);
 
 		 %FIXME: all other fields should belong to other classes
-
-		 %Model general information
-		 notes           = modelfield('default','','marshall',false);
-		 name            = modelfield('default','','marshall',true,'format','String');
 
 		 %Mesh
@@ -209,7 +206,4 @@
 		 waitonlock    = modelfield('default',0,'marshall',true,'format','Boolean');
 
-		 %dummy
-		 dummy = modelfield('default',NaN,'marshall',false);
-
 		 %qmu
 		 variables                       = modelfield('default',struct(),'marshall',false);
@@ -256,7 +250,4 @@
 
 				 % This is a Matlab bug: all the fields of md have their default value
-				 % md.name = {''    [1]    'String'}
-				 % instead of recovering the saved fields
-				 % 
 				 % Example of error message:
 				 % Warning: Error loading an object of class 'model':
@@ -290,8 +281,5 @@
 			 switch nargin
 				 case 0
-
-					 %set default parameters
 					 md=setdefaultparameters(md);
-
 				 case 1
 					 in=varargin{1};
@@ -324,17 +312,17 @@
 			 %name
 			 disp(sprintf('   Name:'));
-			 if isempty(md.name),
+			 if isempty(md.miscellaneous.name),
 				 disp(sprintf('      N/A'));
 			 else
-				 disp(sprintf('      %s',md.name));
-			 end
-
-			 %notes: md.notes is a cell array of strings
+				 disp(sprintf('      %s',md.miscellaneous.name));
+			 end
+
+			 %notes: md.miscellaneous.notes is a cell array of strings
 			 disp(sprintf('   Notes:'));
-			 if isempty(md.notes),
+			 if isempty(md.miscellaneous.notes),
 				 disp(sprintf('      N/A'));
 			 else
-				 if iscell(md.notes),
-					 strings=md.notes;
+				 if iscell(md.miscellaneous.notes),
+					 strings=md.miscellaneous.notes;
 					 for i=1:length(strings),
 						 string=char(strings(i));
@@ -345,6 +333,6 @@
 						 end
 					 end
-				 elseif ischar(md.notes),
-					 disp(sprintf('      %s',md.notes));
+				 elseif ischar(md.miscellaneous.notes),
+					 disp(sprintf('      %s',md.miscellaneous.notes));
 				 else
 					 disp('display error message: ''notes'' for model is neither a cell array of string, nor a string. Cannot display.');
@@ -430,4 +418,7 @@
 			 if isfield(structmd,'hydro_CR'), md.hydrology.CR=structmd.hydro_CR; end
 			 if isfield(structmd,'hydro_kn'), md.hydrology.kn=structmd.hydro_kn; end
+			 if isfield(structmd,'name'), md.miscellaneous.name=structmd.name; end
+			 if isfield(structmd,'notes'), md.miscellaneous.notes=structmd.notes; end
+			 if isfield(structmd,'dummy'), md.miscellaneous.dummy=structmd.dummy; end
 
 			 %Field changes
@@ -544,4 +535,5 @@
 			 md.settings=settings;
 			 md.radaroverlay=radaroverlay;
+			 md.miscellaneous=miscellaneous;
 
 			 %Materials parameters
Index: /issm/trunk/src/m/qmu/preqmu.m
===================================================================
--- /issm/trunk/src/m/qmu/preqmu.m	(revision 9624)
+++ /issm/trunk/src/m/qmu/preqmu.m	(revision 9625)
@@ -33,6 +33,6 @@
 cd(options.qmudir)
 
-%when running in library mode, the in file needs to be called md.name.qmu.in
-options.qmufile=[md.name ];
+%when running in library mode, the in file needs to be called md.miscellaneous.name.qmu.in
+options.qmufile=[md.miscellaneous.name ];
 
 %retrieve variables and resposnes for this particular analysis.
@@ -74,5 +74,5 @@
 %create in file for dakota
 dakota_in_data(md.qmu_method(options.imethod),variables,responses,md.qmu_params(options.iparams),options.qmufile);
-system(['rm -rf ' md.name '.m']);
+system(['rm -rf ' md.miscellaneous.name '.m']);
 
 %build a list of variables and responses descriptors. the list is not expanded. {{{1